@@ -5,4 +5,4 @@ from ._version import get_versions
 __version__ = get_versions()["version"]
 del get_versions
 
-from .meer_tec import XPort, TEC
+from .meer_tec import TEC, XPort  # noqa: F401, E402
